# dictionary-ordinal-number-notation

Commentary by author:  

📖 [辞書順記数法 (Dictionary Ordinal Number Notation)](https://crieit.net/posts/Dictionary-Ordinal-Number-Notation)  

# Install

```shell
pip install dicordnum
```

# Explanation

```plaintext
1
2
3
4
5
6
7
8
9
...
```

```plaintext
1
10
2
3
4
5
6
7
8
9
```

Ouch!  

Let's solve.  

```plaintext
1
2
3
4
5
6
7
8
9
...
```

```plaintext
1
2
3
4
5
6
7
8
9
A10
```

?!  

```plaintext
A91
A92
A93
A94
A95
A96
A97
A98
A99
...
```

```plaintext
A91
A92
A93
A94
A95
A96
A97
A98
A99
AA100
```

It's ok.  

👇 For snake_case

```plaintext
7
a77
aa777
aaa7777
```
